==> dl.php?src=linea21_1_4.zip: linea21/library/scripts/languages/he.js <==
{
    "AUTHORIZATION_REQUIRED": "אינך מורשה להשתמש בסייר הקבצים",
    "INVALID_ACTION": "פעולה לא חוקית",
    "MODE_ERROR": "שגיאת מצב",
    "DIRECTORY_ALREADY_EXISTS": "התיקייה '%s' כבר קיימת",
    "FILE_ALREADY_EXISTS": "הקובץ '%s' כבר קיים",
    "UNABLE_TO_CREATE_DIRECTORY": "לא ניתן ליצור את התיקיה %s",
    "INVALID_VAR": "משתנה לא חוקי %s",
    "DIRECTORY_NOT_EXIST": "התיקייה %s אינה קיימת",
    "UNABLE_TO_OPEN_DIRECTORY": "לא ניתן לפתוח את התיקיה %s",
    "ERROR_RENAMING_DIRECTORY": "שגיאה בעת ניסיון לשנות את התיקייה %s ל %s",
    "ERROR_RENAMING_FILE": "שגיאה בעת ניסיון לשנות את הקובץ %s ל %s",
    "INVALID_DIRECTORY_OR_FILE": "תיקייה או קובץ אינם נכונים",
    "INVALID_FILE_UPLOAD": "קובץ לא חוקי להעלאה לשרת",
    "UPLOAD_FILES_SMALLER_THAN": "בבקשה העלה רק קבצים אשר קטנים מ %s",
    "UPLOAD_IMAGES_ONLY": "בבקשה העלה רק תמונות, קבצים אחרים אינם נתמכים",
    "UPLOAD_IMAGES_TYPE_JPEG_GIF_PNG": "בבקשה העלה רק תמונות מסוג: JPG, JPEG, GIF, PNG",
    "FILE_DOES_NOT_EXIST": "הקובץ %s אינו קיים",
    "LANGUAGE_FILE_NOT_FOUND": "Language file not found",
    "default_foldername": "My folder",
    "prompt_foldername": "הכנס שם לתיקייה החדשה",
    "no_foldername": "לא הוכנס שם תיקייה",
    "create_folder": "צור תיקייה",
    "cancel": "ביטול",
    "select_from_left": "בחר פריט משמאל",
    "fck_select_integration": "The 'Select' function is only used for integration with FCKEditor.",
    "new_filename": "הכנס שם חדש לקובץ",
    "successful_rename": "השם שונה בהצלחה",
    "rename": "שנה שם",
    "confirmation_delete": "?האם אתה בטוח שברצונך למחוק קובץ זה",
    "successful_delete": "הקובץ נמחק",
    "successful_added_file": "הקובץ נוסף בהצלחה",
    "successful_added_folder": "התיקייה החדשה נוספה בהצלחה",
    "select": "בחר",
    "download": "הורד",
    "del": "מחק",
    "parentfolder": "תיקיית אב",
    "dimensions": "מימדים",
    "created": "נוצר",
    "modified": "שונה לאחרונה",
    "size": "גודל",
    "name": "שם",
    "could_not_retrieve_folder": "לא ניתן לקרוא את תוכן התיקייה",
    "yes": "כן",
    "no": "לא",
    "upload": "העלה קובץ",
    "new_folder": "תיקייה חדשה",
    "grid_view": "עבור לתצוגת רשת",
    "list_view": "עבור לתצוגת רשימה",
    "current_folder": "תיקייה נוכחית: ",
    "bytes": " bytes",
    "kb": "kb",
    "mb": "mb",
    "gb": "gb"
}

==> dl.php?src=linea21_1_6.zip: linea21/library/scripts/languages/he.js <==
{
    "ALLOWED_FILE_TYPE": "Only following files are allowed : ", 
    "AUTHORIZATION_REQUIRED": "אינך מורשה להשתמש בסייר הקבצים", 
    "DIRECTORY_ALREADY_EXISTS": "התיקייה '%s' כבר קיימת", 
    "DIRECTORY_NOT_EXIST": "התיקייה %s אינה קיימת", 
    "DISALLOWED_FILE_TYPE": "Following files are not allowed : ", 
    "ERROR_RENAMING_DIRECTORY": "שגיאה בעת ניסיון לשנות את התיקייה %s ל %s", 
    "ERROR_RENAMING_FILE": "שגיאה בעת ניסיון לשנות את הקובץ %s ל %s", 
    "FILE_ALREADY_EXISTS": "הקובץ '%s' כבר קיים", 
    "FILE_DOES_NOT_EXIST": "הקובץ %s אינו קיים", 
    "INVALID_ACTION": "פעולה לא חוקית", 
    "INVALID_DIRECTORY_OR_FILE": "תיקייה או קובץ אינם נכונים", 
    "INVALID_FILE_TYPE": "File upload is not allowed.", 
    "INVALID_FILE_UPLOAD": "קובץ לא חוקי להעלאה לשרת", 
    "INVALID_VAR": "משתנה לא חוקי %s", 
    "LANGUAGE_FILE_NOT_FOUND": "Language file not found", 
    "MODE_ERROR": "שגיאת מצב", 
    "UNABLE_TO_CREATE_DIRECTORY": "לא ניתן ליצור את התיקיה %s", 
    "UNABLE_TO_OPEN_DIRECTORY": "לא ניתן לפתוח את התיקיה %s", 
    "UPLOAD_FILES_SMALLER_THAN": "בבקשה העלה רק קבצים אשר קטנים מ %s", 
    "UPLOAD_IMAGES_ONLY": "בבקשה העלה רק תמונות, קבצים אחרים אינם נתמכים", 
    "UPLOAD_IMAGES_TYPE_JPEG_GIF_PNG": "בבקשה העלה רק תמונות מסוג: JPG, JPEG, GIF, PNG", 
    "browse": "Browse...", 
    "bytes": " bytes", 
    "cancel": "ביטול", 
    "confirmation_delete": "?האם אתה בטוח שברצונך למחוק קובץ זה", 
    "could_not_retrieve_folder": "לא ניתן לקרוא את תוכן התיקייה", 
    "create_folder": "צור תיקייה", 
    "created": "נוצר", 
    "current_folder": "תיקייה נוכחית: ", 
    "default_foldername": "My folder", 
    "del": "מחק", 
    "dimensions": "מימדים", 
    "download": "הורד", 
    "fck_select_integration": "The 'Select' function is only used for integration with FCKEditor.", 
    "file_size_limit": "The file size limit is : ", 
    "file_too_big": "The file is too big.", 
    "gb": "gb", 
    "grid_view": "עבור לתצוגת רשת", 
    "kb": "kb", 
    "list_view": "עבור לתצוגת רשימה", 
    "loading_data": "Transferring data ...", 
    "mb": "mb", 
    "modified": "שונה לאחרונה", 
    "name": "שם", 
    "new_filename": "הכנס שם חדש לקובץ", 
    "new_folder": "תיקייה חדשה", 
    "no": "לא", 
    "no_foldername": "לא הוכנס שם תיקייה", 
    "parentfolder": "תיקיית אב", 
    "prompt_foldername": "הכנס שם לתיקייה החדשה", 
    "rename": "שנה שם", 
    "search": "Search", 
    "search_reset": "Reset", 
    "select": "בחר", 
    "select_from_left": "בחר פריט משמאל", 
    "size": "גודל", 
    "successful_added_file": "הקובץ נוסף בהצלחה", 
    "successful_added_folder": "התיקייה החדשה נוספה בהצלחה", 
    "successful_delete": "הקובץ נמחק", 
    "successful_rename": "השם שונה בהצלחה", 
    "upload": "העלה קובץ", 
    "yes": "כן"
}
